bayespy.nodes.GaussianMarkovChain.broadcasting_multiplier
=========================================================

.. currentmodule:: bayespy.nodes

.. automethod:: GaussianMarkovChain.broadcasting_multiplier